@@ -2,6 +2,7 @@
 The main function of pygeoweaver
 To run in CLI mode. 
 """
+import logging
 import os
 import typing
 import click
@@ -23,13 +24,19 @@ from pygeoweaver import (
     helpwith,
 )
 from pygeoweaver.constants import GEOWEAVER_DEFAULT_ENDPOINT_URL
-from pygeoweaver.sc_create import create_process, create_process_from_file, create_workflow
-from pygeoweaver.sc_detail import get_process_code
-from pygeoweaver.sc_find import get_process_by_id, get_process_by_language, get_process_by_name
-from pygeoweaver.sc_history import get_process_history, get_workflow_history
-from pygeoweaver.sc_list import list_processes_in_workflow
-from pygeoweaver.sc_sync import sync, sync_workflow
-from pygeoweaver.server import show
+from pygeoweaver.commands.pgw_create import create_process, create_process_from_file, create_workflow
+from pygeoweaver.commands.pgw_detail import get_process_code
+from pygeoweaver.commands.pgw_find import get_process_by_id, get_process_by_language, get_process_by_name
+from pygeoweaver.commands.pgw_history import get_process_history, get_workflow_history
+from pygeoweaver.commands.pgw_list import list_processes_in_workflow
+from pygeoweaver.commands.pgw_sync import sync, sync_workflow
+from pygeoweaver.log_config import setup_logging
+from pygeoweaver.server import check_geoweaver_status, show
+from halo import Halo
+from pygeoweaver.utils import get_spinner
+
+
+setup_logging()
 
 
 @click.group()
@@ -41,12 +48,13 @@ def geoweaver():
 
 
 @geoweaver.command("start")
-@click.option('--force', is_flag=True, help='Force overwrite the Geoweaver JAR file if it already exists.')
-def start_command(force):
+@click.option('--force-download', is_flag=True, help='Force overwrite the Geoweaver JAR file if it already exists.')
+@click.option('--force-restart', is_flag=True, help='Force to restart Geoweaver even when it is already running.')
+def start_command(force_download, force_restart):
     """
     Start the Geoweaver application.
     """
-    start(force)
+    start(force_download=force_download, force_restart=force_restart, exit_on_finish=True)
 
 
 @geoweaver.command("stop")
@@ -54,7 +62,7 @@ def stop_command():
     """
     Start the Geoweaver application.
     """
-    stop()
+    stop(exit_on_finish=True)
 
 @geoweaver.command("show")
 @click.option('--geoweaver-url', default=GEOWEAVER_DEFAULT_ENDPOINT_URL, help='Geoweaver URL (default is GEOWEAVER_DEFAULT_ENDPOINT_URL)')
@@ -459,6 +467,7 @@ def sync_process_command(process_id: str, local_path: typing.Union[str, os.PathL
     :param direction: The direction of the sync, either "download" or "upload".
     :type direction: str
     """
+    
     sync(process_id, local_path, direction)
     
 
@@ -475,8 +484,24 @@ def sync_workflow_command(workflow_id: str, sync_to_path: typing.Union[str, os.P
     :param sync_to_path: The local path to sync the Geoweaver workflow.
     :type sync_to_path: Union[str, os.PathLike]
     """
+    
     sync_workflow(workflow_id, sync_to_path)
 
 
+@geoweaver.command("status")
+def status():
+    """
+    Check the status of Geoweaver.
+    """
+    with get_spinner(text='Checking Geoweaver status...', spinner='dots'):
+        geoweaver_running = check_geoweaver_status()
+    
+    if geoweaver_running:
+        click.echo(click.style("Geoweaver is running", fg='green', bold=True))
+    else:
+        click.echo(click.style("Geoweaver is not running", fg='red', bold=True))
+    
+
+
 if __name__ == "__main__":
     geoweaver()
