@@ -7,7 +7,7 @@ import tarfile
 import zipfile
 import urllib.request
 
-from pygeoweaver.utils import get_home_dir, get_java_bin_path
+from pygeoweaver.utils import get_home_dir, get_java_bin_path, safe_exit
 
 
 def install_jdk():
@@ -109,7 +109,44 @@ def extract_zip_archive(archive_path, destination_dir):
     print(f"{archive_path} extracted to {destination_dir}.")
 
 
-def set_jdk_env_vars(jdk_install_dir):
+def set_jdk_env_vars_for_windows(jdk_install_dir):
+    print(f"Setting JDK environment variables for Windows...")
+    java_bin = os.path.join(jdk_install_dir, "bin")
+
+    # Append JAVA_HOME to the user's PATH environment variable
+    try:
+        import winreg  # winreg module is only available on windows and should not be globally imported.
+
+        with winreg.OpenKey(
+            winreg.HKEY_LOCAL_MACHINE,
+            "SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment",
+            0,
+            winreg.KEY_ALL_ACCESS,
+        ) as regkey:
+            current_path = winreg.QueryValueEx(regkey, "PATH")[0]
+            print(f"current_path = {current_path}")
+            if java_bin not in current_path:
+                new_path = f"{current_path};{java_bin}"
+                winreg.SetValueEx(regkey, "PATH", 0, winreg.REG_EXPAND_SZ, new_path)
+                print(f"Added JDK bin directory to PATH: {java_bin}")
+                subprocess.call(["setx", "PATH", ";".join([current_path, java_bin])])
+                print("JDK environment variables set.")
+    except Exception as e:
+        print(f"Error adding JDK bin directory to PATH: {e}")
+
+    # Set JAVA_HOME environment variable
+    # try:
+    #     with winreg.OpenKey(winreg.HKEY_CURRENT_USER, "Environment", 0, winreg.KEY_ALL_ACCESS) as regkey:
+    #         winreg.SetValueEx(regkey, "JAVA_HOME", 0, winreg.REG_EXPAND_SZ, jdk_install_dir)
+    #         print("Set JAVA_HOME environment variable.")
+    # except Exception as e:
+    #     print(f"Error setting JAVA_HOME environment variable: {e}")
+
+    # Update the environment variables of the current process
+    # subprocess.call(["setx", "JAVA_HOME", java_home])
+
+
+def set_jdk_env_vars_for_linux_mac(jdk_install_dir):
     print(f"Setting JDK environment variables...")
     java_line = f'\nexport JAVA_HOME="{jdk_install_dir}"\n'
 
@@ -129,6 +166,14 @@ def set_jdk_env_vars(jdk_install_dir):
     subprocess.run(["bash", "-c", "source ~/.bashrc"])
 
 
+def set_jdk_env_vars(jdk_install_dir):
+    print(f"Setting environment variables for {platform.system()}")
+    if platform.system() == "Windows":
+        set_jdk_env_vars_for_windows(jdk_install_dir)
+    else:
+        set_jdk_env_vars_for_linux_mac(jdk_install_dir)
+
+
 def install_java():
     system = platform.system()
     if system == "Darwin":
@@ -151,7 +196,7 @@ def install_java():
             os.system(f"sudo {package_manager} install -y default-jre default-jdk")
         else:
             print("Package manager not found. Unable to install Java.")
-            sys.exit(1)
+            safe_exit(1)
     elif system == "Windows":
         # note: this requires admin access to the pc, else it will fail saying
         # Access to the path 'C:\ProgramData\chocolatey\lib-bad' is denied.
@@ -163,7 +208,7 @@ def install_java():
         os.system("choco install -y openjdk")
     else:
         print("Unsupported operating system.")
-        sys.exit(1)
+        safe_exit(1)
 
 
 def is_java_installed():
