@@ -10,8 +10,8 @@ from pygeoweaver import start, stop
 import unittest
 
 from pygeoweaver.constants import GEOWEAVER_DEFAULT_ENDPOINT_URL
+from pygeoweaver.log_config import get_logger
 from pygeoweaver.server import show
-from pygeoweaver.utils import get_logger
 
 
 logger = get_logger(__name__)
@@ -26,19 +26,19 @@ class TestServer(unittest.TestCase):
             200,
             f"Failed to access URL: {GEOWEAVER_DEFAULT_ENDPOINT_URL}",
         )
-        stop()
+        stop(exit_on_finish=False)
         with self.assertRaises(requests.exceptions.ConnectionError):
             response = requests.get(GEOWEAVER_DEFAULT_ENDPOINT_URL)
 
-        stop()  # stop again should have no issue
+        stop(exit_on_finish=False)  # stop again should have no issue
 
     def test_windows(self):
         with patch("pygeoweaver.server.checkOS") as mock_checkos:
             mock_checkos.return_value = 3
             with self.assertRaises(RuntimeError):
-                start()
+                start(exit_on_finish=False)
             with self.assertRaises(RuntimeError):
-                stop()
+                stop(exit_on_finish=False)
 
     def test_show_gui(self):
         with patch("pygeoweaver.webbrowser.open") as mock_browser_open:
